@@ -76,15 +76,6 @@ static void file_changed (GnomeVFSMonitorHandle *handle,
 
 static void applet_destroy(GtkObject *widget)
 {
-	/*PersonalLauncher *plugin=PERSONAL_LAUNCHER(widget);
-	if (plugin->fileMon)
-	{
-		gnome_vfs_monitor_cancel(plugin->fileMon);
-	}
-	if (plugin->updateTimeout)
-	{
-		g_source_remove(plugin->updateTimeout);
-	}*/
 	gtk_object_destroy(widget);
 }
 
@@ -93,13 +84,6 @@ static void applet_size_request(GtkWidget *widget, GtkRequisition *requisition)
 	GTK_WIDGET_CLASS(personal_launcher_parent_class)->size_request(
 			widget, requisition);
 	
-	requisition->width = APPLET_WIDTH;
-	requisition->height = APPLET_HEIGHT;
-}
-
-static void applet_style_set(GtkWidget *widget, GtkStyle *old_style)
-{
-
 }
 
 static gint applet_expose(GtkWidget *widget, GdkEventExpose *event)
@@ -181,26 +165,26 @@ static gint applet_expose(GtkWidget *widget, GdkEventExpose *event)
 static void applet_realize(GtkWidget *widget)
 {
 	GTK_WIDGET_CLASS(personal_launcher_parent_class)->realize(widget);
-	applet_style_set(widget, NULL);
 }
 
-static void activation_animation(GtkWidget *widget, GdkEventButton *event, gint iconSize)
+static void activation_animation(GtkWidget *widget, GdkEventButton *event, gint trans)
 {
-	if (iconSize>0)
+	if (trans>=0)
 	{
-		GdkPixbufSimpleAnim *anim=gdk_pixbuf_simple_anim_new(iconSize,iconSize,25);
 		gint width,height;
 
 		GdkPixbuf *orig=gtk_image_get_pixbuf(gtk_bin_get_child(GTK_BIN(widget)));
 		width=gdk_pixbuf_get_width(orig);
 		height=gdk_pixbuf_get_height(orig);
+		GdkPixbufSimpleAnim *anim=gdk_pixbuf_simple_anim_new(width,height,30);
+
 		gint i;
-		for (i=0;i<iconSize/2;i++)
+		for (i=1;i<width/4;i+=2)
 		{
 			GdkPixbuf *icon=gdk_pixbuf_scale_simple(orig,width-(i*2),height-(i*2),GDK_INTERP_NEAREST);
-			GdkPixbuf *good=gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,iconSize,iconSize);
+			GdkPixbuf *good=gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,width,height);
 			gdk_pixbuf_fill(good,0x00000000);
-			gdk_pixbuf_composite(icon,good,0,0,width-i,height-i,i,i,1,1,GDK_INTERP_NEAREST,127);
+			gdk_pixbuf_composite(icon,good,0,0,width,height,0,0,1,1,GDK_INTERP_NEAREST,trans);
 			gdk_pixbuf_simple_anim_add_frame(anim,good);
 			gdk_pixbuf_unref(icon);
 			gdk_pixbuf_unref(good);
@@ -449,7 +433,7 @@ static void create_ui(PersonalLauncher *plugin)
 				}
 				if (animation)
 				{
-					g_signal_connect(G_OBJECT(event),"button-press-event",G_CALLBACK(activation_animation),iconSize+1);
+					g_signal_connect(G_OBJECT(event),"button-press-event",G_CALLBACK(activation_animation),trans);
 				}
 				else
 				{
@@ -489,7 +473,7 @@ static void create_ui(PersonalLauncher *plugin)
 		g_object_unref(G_OBJECT(icon));
 		gtk_container_add(GTK_CONTAINER(event),image);
 
-		g_signal_connect(G_OBJECT(event),"button-press-event",G_CALLBACK(activation_animation),65);
+		g_signal_connect(G_OBJECT(event),"button-press-event",G_CALLBACK(activation_animation),255);
 
 		g_signal_connect(G_OBJECT(event),"button-release-event",G_CALLBACK(execute_command),-1);
 
@@ -581,6 +565,6 @@ static void personal_launcher_class_init(PersonalLauncherClass *klass)
 
 	widget_class->expose_event = applet_expose;
 	widget_class->realize = applet_realize;
-	widget_class->style_set = applet_style_set;
+
 	widget_class->size_request = applet_size_request;
 }
